==> gerbera_1.1.0+dfsg.orig.tar.xz: gerbera-1.1.0/src/web/action.cc <==
/*MT*
    
    MediaTomb - http://www.mediatomb.cc/
    
    action.cc - this file is part of MediaTomb.
    
    Copyright (C) 2005 Gena Batyan <bgeradz@mediatomb.cc>,
                       Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
    
    Copyright (C) 2006-2010 Gena Batyan <bgeradz@mediatomb.cc>,
                            Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                            Leonhard Wimmer <leo@mediatomb.cc>
    
    MediaTomb is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License version 2
    as published by the Free Software Foundation.
    
    MediaTomb is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
    
    You should have received a copy of the GNU General Public License
    version 2 along with MediaTomb; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
    
    $Id$
*/

/// \file action.cc

#include "pages.h"
#include "content_manager.h"

using namespace zmm;
using namespace mxml;

web::action::action() : WebRequestHandler()
{
}

void web::action::process()
{
    log_debug("action: start\n");
    check_request();
    
    String action = param(_("action"));
    if (!string_ok(action))
        throw _Exception(_("No action given!"))
            ;
    log_debug("action: %s\n", action.c_str());

#ifdef YOUTUBE
    if (action == UI_ACTION_REFRESH_YOUTUBE)
    {
        ContentManager::getInstance()->fetchOnlineContent(OS_YouTube, true, true, true);
    }
#endif

    log_debug("action: returning\n");
}

==> gerbera_2.0.0+dfsg.orig.tar.xz: gerbera-2.0.0/src/web/action.cc <==
/*MT*

    MediaTomb - http://www.mediatomb.cc/

    action.cc - this file is part of MediaTomb.

    Copyright (C) 2005 Gena Batyan <bgeradz@mediatomb.cc>,
                       Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>

    Copyright (C) 2006-2010 Gena Batyan <bgeradz@mediatomb.cc>,
                            Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                            Leonhard Wimmer <leo@mediatomb.cc>

    Copyright (C) 2016-2023 Gerbera Contributors

    MediaTomb is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License version 2
    as published by the Free Software Foundation.

    MediaTomb is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    version 2 along with MediaTomb; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.

    $Id$
*/

/// \file action.cc
#define LOG_FAC log_facility_t::web

#include "pages.h" // API

#include "config/config_manager.h"
#include "content/content_manager.h"
#include "util/xml_to_json.h"

void Web::Action::process()
{
    log_debug("action: start");
    checkRequest();

    std::string action = param("action");
    if (action.empty())
        throw_std_runtime_error("No action given");
    log_debug("action: {}", action);

    log_debug("action: returning");
}
